@@ -1,4 +1,4 @@
-/*
+    /*
  * ark -- archiver for the KDE project
  *
  * Copyright (C) 2009 Harald Hvaal <haraldhv@stud.ntnu.no>
@@ -31,7 +31,7 @@
 
 using namespace Kerfuffle;
 
-K_PLUGIN_FACTORY(CliPluginFactory, registerPlugin< CliPlugin >();)
+K_PLUGIN_FACTORY_WITH_JSON(CliPluginFactory, "kerfuffle_clirar.json", registerPlugin<CliPlugin>();)
 
 CliPlugin::CliPlugin(QObject *parent, const QVariantList& args)
         : CliInterface(parent, args)
@@ -119,6 +119,7 @@ ParameterList CliPlugin::parameterList() const
                                                     << QStringLiteral( "Cannot find volume" );
         p[CorruptArchivePatterns] = QStringList() << QStringLiteral("Unexpected end of archive")
                                                   << QStringLiteral("the file header is corrupt");
+        p[DiskFullPatterns] = QStringList() << QStringLiteral("No space left on device");
     }
 
     return p;
